@@ -9,9 +9,12 @@ import os
 import re
 from collections import defaultdict
 from yaml import load
-from yaml import CLoader as Loader
 from .output import (print_job, print_success, print_failed_and_exit,
                      print_skipped)
+try:
+    from yaml import CLoader as Loader
+except ImportError:
+    from yaml import Loader
 
 TESTCASE_FILE = 'testcases.yaml'
 TESTAPI_URI_VAR = 'TEST_DB_URL'
@@ -33,11 +36,11 @@ def get_testapi_url():
     return print_failed_and_exit(
         f'Bad testapi url variable {TESTAPI_URI_VAR} format: {api}')
 
-def get_pods_list():
+def get_pods_list(src_folder = '.'):
     """Get pods list."""
-    print_job(f'📤 read {PODS_FILE}')
+    print_job(f'📤 read {src_folder}/{PODS_FILE}')
     try:
-        with open(PODS_FILE, 'r') as file:
+        with open(f"{src_folder}/PODS_FILE", 'r', encoding='utf-8') as file:
             pods = load(file, Loader=Loader)['pods']
         print_success()
         return pods
@@ -47,14 +50,14 @@ def get_pods_list():
             print_job(f'📤 get pods from ENV {NODE_NAME_VAR}')
             print_success()
             return [os.environ.get(NODE_NAME_VAR)]
-        return print_failed_and_exit(
-            f"Missing file '{PODS_FILE}' or var '{NODE_NAME_VAR}")
+        print_skipped(f" - Missing file '{PODS_FILE}' or var '{NODE_NAME_VAR}")
+        return []
 
-def get_testcases():
+def get_testcases(src_folder = '.'):
     """Get testscases from file."""
-    print_job(f'📤 read {TESTCASE_FILE}')
+    print_job(f'📤 read  {src_folder}/{TESTCASE_FILE}')
     try:
-        with open(TESTCASE_FILE, 'r') as file:
+        with open(f"{src_folder}/{TESTCASE_FILE}", 'r', encoding='utf-8') as file:
             testcases = load(file, Loader=Loader)
         print_success()
         return tests_by_project(testcases)
