@@ -7,13 +7,13 @@ Populate testapi with testscases - output messages.
 
 import sys
 
-def print_skipped():
+def print_skipped(msg = ''):
     """Print skipped message."""
-    print('[\033[94mskipped\033[0m]')
+    print(msg + '[\033[94mskipped\033[0m]')
 
-def print_success():
+def print_success(msg = ''):
     """Print success message."""
-    print('[\033[92msuccess\033[0m]')
+    print(msg + '[\033[92msuccess\033[0m]')
 
 def print_failed_and_exit(msg):
     """Print failed message."""
